@@ -112,6 +112,8 @@ Input Frames : \n\
   - [OPTIONAL] The instrument response table (Tag = RESPONSE_MERGE1D_SLIT_arm)\n\
   - [OPTIONAL] An atmospheric extinction table (Tag = ATMOS_EXT_arm)\n\
   - [OPTIONAL] A telluric mask (Tag = TELL_MASK_arm)\n\
+  - [OPTIONAL] The instrument master response table (Tag = MRESPONSE_MERGE1D_SLIT_arm).\n\
+    If both master and individual response are provided the individual response is preferred.\n\
 Products : \n\
   - PREFIX_ORDER2D_arm extracted spectrum, order-by-order, 2D\n\
   - PREFIX_ORDER1D_arm extracted spectrum, order-by-order, 1D\n\
@@ -488,6 +490,7 @@ static void xsh_scired_slit_offset( cpl_parameterlist* parameters,
   int do_computemap=1;
   int use_model=0;
   int cut_uvb_spectrum=0;
+  int scale_nod=0;
   /**************************************************************************/
   /* DFS management */
   /**************************************************************************/
@@ -680,7 +683,7 @@ static void xsh_scired_slit_offset( cpl_parameterlist* parameters,
   sprintf(file_tag,"%s_%s_%s",rec_prefix,XSH_ORDER2D, arm_str) ;
   check(rect2_frameset_tables=xsh_frameset_ext_table_frames(rect_frameset));
   check( comb_frame = xsh_combine_nod(rect2_frameset_tables, combine_nod_param,
-				       file_tag,instrument,&comb_frame_eso));
+				       file_tag,instrument,&comb_frame_eso,scale_nod));
   xsh_free_frameset(&rect2_frameset_tables);
 
 
@@ -932,7 +935,7 @@ static void xsh_scired_slit_offset( cpl_parameterlist* parameters,
 
     xsh_free_frameset(&sky_bias);
     xsh_free_frameset(&sky_dark);
-
+    xsh_free_frame(&bpmap);
     xsh_free_frame(&wavemap) ;
     xsh_free_frame(&slitmap) ;
     xsh_free_frame(&loc_table_frame) ;
